@@ -65,7 +65,6 @@ ddf.io<-function(dsmodel,mrmodel,data,meta.data=list(),control=list(),call=""){
   # Process data
   data.list <- process.data(data,meta.data)
   meta.data <- data.list$meta.data
-  xmat <- data.list$xmat
 
   # Create result list
   result <- list(call=call, data=data, mrmodel=mrmodel, dsmodel=dsmodel,
@@ -83,8 +82,7 @@ ddf.io<-function(dsmodel,mrmodel,data,meta.data=list(),control=list(),call=""){
   result$meta.data <- result$ds$meta.data
   if(is.null(result$ds$Nhat)){
     if(control$debug){
-      errors("ds model did not converge; no further results possible")
-      errors("Returned object is for debugging ONLY!")
+      warning("ds model did not converge; no further results possible\nReturned object is for debugging ONLY!")
       return(result)
     }
     stop("ds model did not converge; no further results possible")
