@@ -1,60 +1,28 @@
 #' Variance and confidence intervals for density and abundance estimates
 #'
-#' Computes standard error, cv, and log-normal confidence intervals for
-#' abundance and density within each region (if any) and for the total of all
-#' the regions.  It also produces the correlation matrix for regional and total
-#' estimates.
+#' Computes standard error, cv, and log-normal confidence intervals for abundance and density within each region (if any) and for the total of all the regions. It also produces the correlation matrix for regional and total estimates.
 #'
-#' The variance has two components: 1) variation due to uncertanity from
-#' estimation of the detection function and 2) variation in abundance due to
-#' random sample selection.  The first component is computed using a delta
-#' method estimate of variance (\code{\link{DeltaMethod}} (Huggins 1989, 1991,
-#' Borchers et al. 1998) in which the first derivatives of the abundance
-#' estimator with respect to the parameters in the detection function are
-#' computed numerically.  The second component can be computed in one of three
-#' ways as set by the option \code{varflag} with values 0,1,2.
+#' The variance has two components:
+#' \itemize{
+#'   \item variation due to uncertainty from estimation of the detection function parameters;
+#'   \item variation in abundance due to random sample selection;
+#' }
+#' The first component (model parameter uncertainty) is computed using a delta method estimate of variance (Huggins 1989, 1991, Borchers et al. 1998) in which the first derivatives of the abundance estimator with respect to the parameters in the detection function are computed numerically (see \code{\link{DeltaMethod}}).
 #'
-#' A value of 0 is to use a binomial variance for the number of observations
-#' and it is only useful if the sampled region is the survey region and the
-#' objects are not clustered which will not occur very often. If covered region
-#' is less than the survey region the variance estimator is scaled up but it
-#' will be a poor estimator and the confidence interval will likely not achieve
-#' the nominal level.
+#' The second component (encounter rate variance) can be computed in one of several ways depending on the form taken for the encounter rate and the estimator used. To begin with there three possible values for \code{varflag} to calculate encounter rate:
+#' \itemize{
+#'  \item \code{0} uses a binomial variance for the number of observations (equation 13 of Borchers et al. 1998). This estimator is only useful if the sampled region is the survey region and the objects are not clustered; this situation will not occur very often;
+#'  \item \code{1} uses the encounter rate \eqn{n/L} (objects observed per unit transect) from Buckland et al. (2001) pg 78-79 (equation 3.78) for line transects (see also Fewster et al, 2009 estimator R2). This variance estimator is not appropriate if \code{size} or a derivative of \code{size} is used in the detection function;
+#'  \item \code{2} is the default and uses the encounter rate estimator \eqn{\hat{N}/L} (estimated abundance per unit transect) suggested by Innes et al (2002) and Marques & Buckland (2004).
+#' }
 #'
-#' A value of 1 uses the variance for the encounter rate of (Fewster et al.
-#' (2009), estimator R2 (which has been shown to have better properties than
-#' the previous default of Buckland et al. 2001 pg 78-79)).  If
-#' \code{group=FALSE} the variance of the mean group size is also included.
-#' This variance estimator is not appropriate if \code{size} or a derivative of
-#' \code{size} is used in the any of the detection function models.
+#' In general if any covariates are used in the models, the default \code{varflag=2} is preferable as the estimated abundance will take into account variability due to covariate effects. If the population is clustered the mean group size and standard error is also reported.
 #'
-#' In general if any covariates are used in the models, the default option 2 is
-#' preferable.  It uses a variance estimator based on that suggested by Innes
-#' et al. (2002) which used the formula for the variance ecounter rate but
-#' replaces the number of observations per sample with the estimated abundance
-#' per sample.  The difference between the version used here and that in Innes
-#' et al. (2002) is that Innes et al. use an estimator with form similar to
-#' that of Buckland et al. (2001), while the estimator here uses a form based
-#' on Fewster et al. (2009, estimator R2).
+#' For options \code{1} and \code{2}, it is then possible to choose one of the estimator forms given in Fewster et al (2009) : \code{"R2"}, \code{"R3"}, \code{"R4"}, \code{"S1"}, \code{"S2"}, \code{"O1"}, \code{"O2"} or \code{"O3"} by specifying the \code{ervar=} option. By default \code{"R2"} is used. See \code{\link{varn}} and Fewster et al (2009) for further details on these estimators.
 #'
-#' For more on encounter rate variance estimation, see \link{varn}.
+#' Exceptions to the above occur if there is only one sample in a stratum. In that case it uses Poisson assumption (\eqn{Var(x)=x}) and it assumes a known variance so \eqn{z=1.96} is used for critical value. In all other cases the degrees of freedom for the \eqn{t}-distribution assumed for the log(abundance) or log(density) is based on the Satterthwaite approximation (Buckland et al. 2001 pg 90) for the degrees of freedom (df). The df are weighted by the squared cv in combining the two sources of variation because of the assumed log-normal distribution because the components are multiplicative. For combining df for the sampling variance across regions they are weighted by the variance because it is a sum across regions.
 #'
-#' Exceptions to the above occur if there is only one sample in a stratum. In
-#' that case it uses Poisson assumption (var(x)=x) and it assumes a known
-#' variance so z=1.96 is used for critical value. In all other cases the
-#' degrees of freedom for the t-distribution assumed for the log(abundance) or
-#' log(density) is based on the Satterthwaite approximation (Buckland et al.
-#' 2001 pg 90) for the degrees of freedom (df).  The df are weighted by the
-#' squared cv in combining the two sources of variation because of the assumed
-#' log-normal distribution because the components are multiplicative.  For
-#' combining df for the sampling variance across regions they are weighted by
-#' the variance because it is a sum across regions.
-#'
-#' A non-zero correlation between regional estimates can occur from using a
-#' common detection function across regions.  This is reflected in the
-#' correlation matrix of the regional and total estimates which is given in the
-#' value list.  It is only needed if subtotals of regional estimates are
-#' needed.
+#' A non-zero correlation between regional estimates can occur from using a common detection function across regions. This is reflected in the correlation matrix of the regional and total estimates which is given in the value list. It is only needed if subtotals of regional estimates are needed.
 #'
 #' @param model ddf model object
 #' @param region.table table of region values
@@ -65,12 +33,8 @@
 #' @param estimate.table table of estimate values
 #' @param Nhat.by.sample estimated abundances by sample
 #' @export
-#' @return List with 2 elements: \item{estimate.table}{completed table with se,
-#'   cv and confidence limits} \item{vc }{correlation matrix of estimates}
-#' @note This function is called by \code{dht} and it is not expected that the
-#'   user will call this function directly but it is documented here for
-#'   completeness and for anyone expanding the code or using this function in
-#'   their own code
+#' @return List with 2 elements: \item{estimate.table}{completed table with se, cv and confidence limits} \item{vc }{correlation matrix of estimates}
+#' @note This function is called by \code{dht} and it is not expected that the user will call this function directly but it is documented here for completeness and for anyone expanding the code or using this function in their own code.
 #' @author Jeff Laake
 #' @seealso \code{\link{dht}}, \code{\link{print.dht}}
 #' @references see \code{\link{dht}}
@@ -105,7 +69,8 @@ dht.se <- function(model, region.table, samples, obs, options, numRegions,
   if(!is.null(model$par)){
     vcov <- solvecov(model$hessian)$inv
     vc1.list <- DeltaMethod(model$par, dht.deriv, vcov, options$pdelta,
-        model = model, samples = samples, obs = obs, options = options)
+                            model=model, samples=samples, obs=obs,
+                            options=options)
     vc1 <- vc1.list$variance
   }else{
     vc1.list <- list(variance=0)
@@ -132,7 +97,7 @@ dht.se <- function(model, region.table, samples, obs, options, numRegions,
   # with all levels of the Region.Label from the region.table.
   if(sum(region.table$Area) == 0 | options$varflag == 0){
     if(options$group){
-      vc2 <- by((1 - obs$pdot)/obs$pdot^2, obs$Region.Label,sum)
+      vc2 <- by((1 - obs$pdot)/obs$pdot^2, obs$Region.Label, sum)
     }else{
       vc2 <- by(obs$size^2 * (1 - obs$pdot)/obs$pdot^2, obs$Region.Label, sum)
     }
@@ -196,7 +161,8 @@ dht.se <- function(model, region.table, samples, obs, options, numRegions,
     }
 
     # sort Nhat.by.sample by Region.Label and Sample.Label
-    Nhat.by.sample <- Nhat.by.sample[order(Nhat.by.sample$Region.Label,Nhat.by.sample$Sample.Label),]
+    Nhat.by.sample <- Nhat.by.sample[order(Nhat.by.sample$Region.Label,
+                                           Nhat.by.sample$Sample.Label),]
 
     # Loop over each region and compute each variance;
     # jll 11/11/04 - changes made in following code using
@@ -220,12 +186,12 @@ dht.se <- function(model, region.table, samples, obs, options, numRegions,
         }
       }else if (options$varflag == 1){
         vc2[i] <- (Ni * Li)^2 * varn(stratum.data$Effort.x,
-                                     stratum.data$n,type=options$ervar)/
+                                     stratum.data$n, type=options$ervar)/
                                 sum(stratum.data$n)^2 + Ni^2 * vars/sbar^2
       }else{
         if(options$varflag==2){
           vc2[i] <- varn(stratum.data$Effort.x/(scale[i] * Li),
-                         stratum.data$Nhat/scale[i],type=options$ervar)
+                         stratum.data$Nhat/scale[i], type=options$ervar)
         }else{
           vc2[i] <- varn(stratum.data$Effort.x/(scale[i] * Li),
                         stratum.data$Nhat/scale[i], type=options$ervar)
@@ -274,7 +240,7 @@ dht.se <- function(model, region.table, samples, obs, options, numRegions,
     # set df from replicate lines to a min of 1 which avoids divide by zero
     # Following 2 lines added and references to estimate.table$k changed to df
     df <- estimate.table$k
-    df <- sapply(df,compute.df,type=options$ervar)
+    df <- sapply(df, compute.df, type=options$ervar)
     df[df<1] <- 1
 
     if(is.na(vc1) || all(vc1==0)){
@@ -312,7 +278,7 @@ dht.se <- function(model, region.table, samples, obs, options, numRegions,
     # intervals for varflag=0; sets df=0
     # and uses normal approximation
     cvalue <- exp((abs(qnorm(ci.width)) * sqrt(log(1 + estimate.table$cv^2))))
-    estimate.table$df <- rep(0,dim(estimate.table)[1])
+    estimate.table$df <- rep(0, dim(estimate.table)[1])
   }
 
   # deal with missing values and divide by 0 issues
